"""Document handlers."""

from likhit.handlers.ciaa_press_release import CIAAPressReleaseHandler
from likhit.handlers.kanun_patrika import KanunPatrikaHandler

__all__ = ["CIAAPressReleaseHandler", "KanunPatrikaHandler"]
